@@ -2,6 +2,9 @@ module.exports = {
     upgrade: true,
     reject: [
         // API changes break existing tests
-        'proxy'
+        'proxy',
+
+        // API changes
+        'eslint'
     ]
 };
